
{% load i18n %}

<table class="table table-striped aa-sovtimer-campaigns" style="width:100%;">
    <thead>
        <th>{% translate 'Type' %}</th>
        <th>{% translate 'System' %}</th>
        <th>{% translate 'Constellation' %}</th>
        <th>{% translate 'Region' %}</th>
        <th>{% translate 'Owner / Defender' %}</th>
        <th>{% translate 'ADM' %}</th>
        <th>{% translate 'Start' %}</th>
        <th>{% translate 'Remaining' %}</th>
        <th>{% translate 'Progress' %}</th>
    </thead>

    <tbody></tbody>
</table>
